@@ -118,7 +118,7 @@ INSTALLED_APPS = (
     'Theophrastus.editor',
     'Theophrastus.statistics',
     'Theophrastus.cloud',
-    # 'Theophrastus.newsletter_extension',
+    'Theophrastus.newsletter_extension',
     'Theophrastus.document',
     'Theophrastus.integration',
     'Theophrastus.api',
@@ -126,7 +126,7 @@ INSTALLED_APPS = (
     #'editor',
     #'statistics',
     #'cloud',
-    'newsletter_extension',
+    # 'newsletter_extension',
     #'document',
     #'integration',
     #'api',
