@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 9579 2016-03-09 01:43:46Z Judy $
+# $Id: urls.py 10247 2017-09-03 17:57:32Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Judy $
-# $Date: 2016-03-09 09:43:46 +0800 (三, 09  3 2016) $
-# $Revision: 9579 $
+# $Author: David $
+# $Date: 2017-09-04 01:57:32 +0800 (Mon, 04 Sep 2017) $
+# $Revision: 10247 $
 
 from django.conf.urls import url, patterns
 
@@ -24,7 +24,8 @@ urlpatterns = patterns('',
         name='Theophrastus.cloud.getBounces'),
     url(r'^complains/$', views.getComplains,
         name='Theophrastus.cloud.getComplains'),
-
+    url(r'^deliveries/$', views.getDeliveries,
+        name='Theophrastus.cloud.getDeliveries'),
     url(r'^verify/$', views.verifyEmailAddress,
         name='Theophrastus.cloud.ajax.verifyEmailAddress'),
     url(r'^verify/delete/$', views.deleteVerifiedEmailAddress,
