@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 10358 2017-10-09 03:33:51Z David $
+# $Id: views.py 10396 2017-10-23 23:56:24Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-10-09 11:33:51 +0800 (Mon, 09 Oct 2017) $
-# $Revision: 10358 $
+# $Date: 2017-10-24 07:56:24 +0800 (Tue, 24 Oct 2017) $
+# $Revision: 10396 $
 
 import base64
 from datetime import datetime
@@ -123,11 +123,11 @@ def login(request):
     test:
     import urllib
     data = urllib.urlencode({'user': 'admin', 'pwd': 'admin', 'app': 'hgfdd'})
-    print urllib.urlopen('http://nuwa-shiva.servehttp.com:8080/newsletters/
-          api/app/login/', data=data).read()
+    print urllib.urlopen('localhost:8000/newsletters/
+                          api/app/login/', data=data).read()
 
     @param request Request instance.
-    @return JSON type, example: {"token": "XNO9rHkIzWnyaPZ5a1Y_MM3KI623rtk="}
+    @return JSON type, example: {"token": "XNO9rHkIzWnyaPZ5a1Y|MM3KI623rtk="}
     """
     try:
         if not request.method == 'POST':
@@ -150,8 +150,8 @@ def login(request):
                     # 1.
                     generator = TokenGenerator(username)
                     t = datetime.now().strftime('%Y%m%d%H%M%S')
-                    token = generator.getToken('%s_%d' % (t, app.id))
-                    token = '%s_%s' % (username, token)
+                    token = generator.getToken('%s|%d' % (t, app.id))
+                    token = '%s|%s' % (username, token)
                     # 2.
                     generator = TokenGenerator(SECRET_KEY)
                     token = generator.getToken(token)
@@ -180,12 +180,12 @@ def getAppId(token):
         generator = TokenGenerator(SECRET_KEY)
         token = generator.getContent(str(token))
         # 2.
-        _token = token.split('_')
+        _token = token.split('|')
         username = _token.pop(0)
         generator = TokenGenerator(username)
-        content = generator.getContent('_'.join(_token))
+        content = generator.getContent('|'.join(_token))
 
-        _content = content.split('_')
+        _content = content.split('|')
         appId = _content[-1]
         return int(appId)
     except Exception as e:
